Index: src/gpu/GrRecordReplaceDraw.h |
diff --git a/src/gpu/GrRecordReplaceDraw.h b/src/gpu/GrRecordReplaceDraw.h |
index 3ba43dc2f04db764ca9a3122fada0f8e14f87b18..4900e0d2417ec7d34d3faf58866814b2a1929b27 100644 |
--- a/src/gpu/GrRecordReplaceDraw.h |
+++ b/src/gpu/GrRecordReplaceDraw.h |
@@ -16,7 +16,9 @@ class SkBBoxHierarchy; |
class SkBitmap; |
class SkCanvas; |
class SkImage; |
+class SkMatrix; |
class SkPaint; |
+class SkPicture; |
class SkRecord; |
// GrReplacements collects op ranges that can be replaced with |
@@ -58,12 +60,12 @@ private: |
#endif |
}; |
// Draw an SkRecord into an SkCanvas replacing saveLayer/restore blocks with |
// drawBitmap calls. A convenience wrapper around SkRecords::Draw. |
-void GrRecordReplaceDraw(const SkRecord&, |
+void GrRecordReplaceDraw(const SkPicture*, |
SkCanvas*, |
- const SkBBoxHierarchy*, |
const GrReplacements*, |
+ const SkMatrix&, |
SkDrawPictureCallback*); |
#endif // GrRecordReplaceDraw_DEFINED |
@@ -58,12 +60,12 @@ private: |
#endif |
}; |
-// Draw an SkRecord into an SkCanvas replacing saveLayer/restore blocks with |
+// Draw an SkPicture into an SkCanvas replacing saveLayer/restore blocks with |
// drawBitmap calls. A convenience wrapper around SkRecords::Draw. |